@@ -1,12 +1,13 @@
 package net.reduls.igo.bin;
 
-import java.util.*;
-
 import java.io.IOException;
 import net.reduls.igo.Tagger;
 import net.reduls.igo.Morpheme;
 import net.reduls.igo.util.ReadLine;
 
+/**
+ * 形態素解析コマンド
+ */
 public final class Igo {
     public static void main(String[] args) throws IOException {
 	if(!(args.length==1 || args.length==2) ||
@@ -21,7 +22,6 @@ public final class Igo {
 	final ReadLine rl = new ReadLine(System.in);
 	if(wakati)
 	    for(String s=rl.read(); s != null; s=rl.read()) {
-		tg.wakati(s);
 		for(String w : tg.wakati(s))
 		    System.out.print(w+" ");
 		System.out.println("");
